#
# spec file for package pantheon-shortcut-overlay
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid io.elementary.shortcut-overlay
Name:           pantheon-shortcut-overlay
Version:        8.0.0
Release:        1.1
Summary:        A native OS-wide shortcut overlay to be launched by Gala
License:        GPL-3.0-or-later
URL:            https://github.com/elementary/shortcut-overlay
Source0:        %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(granite-7)
BuildRequires:  pkgconfig(gtk4)
Provides:       elementary-shortcut-overlay = %{version}
Obsoletes:      elementary-shortcut-overlay < %{version}

%description
This Granite applet should read window manager and OS keyboard shortcuts from
dconf and expose them to the user when launched.

%lang_package

%prep
%autosetup -n shortcut-overlay-%{version}

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{appid}
%fdupes %{buildroot}%{_datadir}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{appid}
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/metainfo/%{appid}.metainfo.xml

%files lang -f %{appid}.lang

%changelog
* Fri Nov  1 2024 Richard Rahl <rrahl0@opensuse.org>
- rename to pantheon-shortcut-overlay
- remove %%suse_update_desktop_file, as it's deprecated
* Sat Aug 10 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.0:
  * Show screen reader shortcut
  * Updated translations
- update to 2.0.1:
  * Show in the applications menu
  * Replace keyboard settings button with a labeled link button
  * Show on-screen keyboard shortcut
  * Close with the shortcut Ctrl + Q
  * Updated translations
- update to 2.0.0:
  * Updated translations
  * updated to gtk4
- update to 1.2.1:
  * Fix the app not launching if a shortcut key is set to blank
  * Updated translations
- update to 1.2.0:
  * Add screenshot shortcuts
  * Fix issues with multiple windows
  * Updated translations
- update to 1.1.2:
  * Updated translations
- update to 1.1.1:
  * Updated translations
- update url to github, as we don't want to link to a different OS
* Mon Nov 25 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.1.0:
  * Add Gettext Updates to Actions
  * Update .travis.yml (#75)
  * Add Release to Actions
  * Add AppData (#74)
  * Add Lint to CI (#73)
  * MainWindow: make style context unowned
  * README: Update weblate badge
  * Fix conflicts with weblate
  * Fix merge conflicts with Weblate
  * Remove unused po files and update LINGUAS
  * Parse accel strings and skip empty strings (#66)
  * ShortcutsView: Display switch layout shortcut (#63)
  * Remove shortcut entry class (#64)
  * More whitespace (#62)
  * Make shortcut label do less (#61)
* Mon Oct  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.0.1:
  * Merge branch 'origin/master' into Weblate
  * Delay destroying window to avoid triggering a re-open (#49)
  * Merge remote-tracking branch 'origin/master'
* Tue Nov  7 2017 avvissu@yandex.by
- Initial package
